# { journal, chronical, evolution, progress, progression, development, continuum, series, history, schedule, line, ancestry, geneology, timeline, posterity, chain, sequence, structures, tables, sequences, blockchains, ledgers }

multiple synchronized tables: [ keys, ellipses ] [ voting ] [ private ] [ public ] [ proposal ] [ private ] [ public ] [ sequences ]: [ squeezes, aggregates ] [ leaps, steps, moves ] [ accords ] [ builders, authors, writers, voters, treasurers, supporters, teachers, chaperones, custodians, ] [ coms ] [ gadgets ] [ petitions ] [ treasure ] [ constants ] [ encyclopedia ]: [ sign, stamp ] [ verify, approve ] the voters: leaps: [{ "1": [{ "kind": "individual", "public_vk": amount: 15000 },{ "kind": "individual", "vk_public": amount: 9000 },{ "proposal": { "unsigned": { kind: "individual", ve_public: amount: 5000 }, "signed": b"" }, "signatures": { [ public instrument key ]: { vote: "yes", # # the "proposal" signed with the "private instrument key" # of the treasurer. # signature: b"" } } }] }] squeezes: [{ "1": [], "2": [{ kind: "individual", ve_public: amount: 15000, fraction: "3/4" },{ kind: "individual", ve_public: amount: 5000, fraction: "1/4" }] }] the leaps: [{ "1": [{ }], "2": [{ }], "3": [{ }] }] the squeezes: [{ "1": [], "2": [] }]